# -*- coding: utf-8 -*-

PAGSEGURO_API_URL = 'https://ws.pagseguro.uol.com.br/v2/checkout'
PAGSEGURO_PAYMENT_URL = 'https://pagseguro.uol.com.br/v2/checkout/payment.html'
PAGSEGURO_NOTIFICATION_URL = 'https://ws.pagseguro.uol.com.br/v2/transactions/notifications/'
